@@ -3,8 +3,8 @@ import threading
 
 from flask import Flask, request
 
-from cloud_spi_core import app
-from cloud_spi_log import log_key
+from py_base_framework.cloud_spi_core import app
+from py_base_framework.cloud_spi_log import log_key
 
 
 class JSONObject:
